// Include the needed files
include("sh_init.lua")
include("cl_scoreboard.lua")


// Decides where  the player view should be (forces third person for props)
function GM:CalcView(pl, origin, angles, fov)
	local view = {} 
	
	if blind then
		view.origin = Vector(20000, 0, 0)
		view.angles = Angle(0, 0, 0)
		view.fov = fov
		
		return view
	end
	
 	view.origin = origin 
 	view.angles	= angles 
 	view.fov = fov 
 	
 	// Give the active weapon a go at changing the viewmodel position 
	if pl:Team() == TEAM_PROPS && pl:GetNWInt("dead") == 0 then
		view.origin = origin + Vector(0, 0, 10) + (angles:Forward() * -80)
	else
	 	local wep = pl:GetActiveWeapon() 
	 	if wep && wep != NULL then 
	 		local func = wep.GetViewModelPosition 
	 		if func then 
	 			view.vm_origin, view.vm_angles = func(wep, origin*1, angles*1) // Note: *1 to copy the object so the child function can't edit it. 
	 		end
	 		 
	 		local func = wep.CalcView 
	 		if func then 
	 			view.origin, view.angles, view.fov = func(wep, pl, origin*1, angles*1, fov) // Note: *1 to copy the object so the child function can't edit it. 
	 		end 
	 	end
	end
 	
 	return view 
end 


// Creates/Recreates the scoreboard
function GM:CreateScoreboard()
	if scoreboard then
		scoreboard:Remove()
		scoreboard = nil
	end

	scoreboard = vgui.Create("scoreboard")
end


// Called by the server on player spawn
function FirstTimeHelp(um)
	if show_help_menu == 1 then
		show_help_menu = 0
		OpenHelpMenu()
	end
end
usermessage.Hook("FirstTimeHelp", FirstTimeHelp)


// Hides the team selection box to the player
function GM:HideTeam()
	if IsValid(self.TeamSelectFrame) then
		self.TeamSelectFrame:Remove()
		self.TeamSelectFrame = nil
	end
end


// We are using VGUI, this is not needed
function GM:HUDDrawScoreBoard()
end


// Paints our HUD on the screen
function GM:HUDPaint()
	if self.ShowScoreboard && IsValid(LocalPlayer()) && LocalPlayer():Team() != TEAM_SPECTATOR && LocalPlayer():GetNWInt("dead") == 0 then
		return
	end
	
	self:HUDDrawPickupHistory()
	
	// Store for later use
	ctr_x = ScrW() / 2
	ctr_y = ScrH() / 2
	
	// Spectator bars
	if IsValid(LocalPlayer()) && LocalPlayer():Alive() && (LocalPlayer():GetNWInt("dead") == 1 || LocalPlayer():Team() == TEAM_SPECTATOR) then
		surface.SetDrawColor(0, 0, 0, 255)
		surface.DrawRect(0, 0, ScrW(), 80)
		surface.DrawRect(0, ScrH() - 80, ScrW(), 80)
	end	
	
	// Draw round timeleft and hunter release timeleft
	if round_start_time != 0 then
		local time_left = ROUND_TIME - (CurTime() - round_start_time)
		if time_left < 0 then time_left = 0 end
		
		draw.RoundedBox(8, 24, 24, 46, 26, Color(0, 0, 0, 75))
		draw.DrawText(string.ToMinutesSeconds(time_left), "ph_arial", 30, 29, Color(255, 220, 0, 255), 0)
		
		local blindlock_time_left = (HUNTER_BLINDLOCK_TIME - (CurTime() - round_start_time)) + 1
		if blindlock_time_left < 1 && blindlock_time_left > -6 then
			blindlock_time_left_msg = "Hunters have been released!"
		elseif blindlock_time_left > 0 then
			blindlock_time_left_msg = "Hunters will be unblinded && released in "..string.ToMinutesSeconds(blindlock_time_left)
		else
			blindlock_time_left_msg = nil
		end
		
		if blindlock_time_left_msg then
			surface.SetFont("ph_arial")
			local tw, th = surface.GetTextSize(blindlock_time_left_msg)
			
			draw.RoundedBox(8, ScrW() - (35 + tw), 20, tw + 10, 25, Color(0, 0, 0, 75))
			draw.DrawText(blindlock_time_left_msg, "ph_arial", ScrW() - 31, 24, Color(255, 220, 0, 255), 2)
		end
	end
	
	self:DrawDeathNotice(0.85, 0.04)
end


// Called every frame
function GM:HUDShouldDraw(name)
	if IsValid(LocalPlayer()) then
		if self.ShowScoreboard && LocalPlayer():Team() != TEAM_SPECTATOR && LocalPlayer():GetNWInt("dead") == 0 then
			return false
		end
		
		local wep = LocalPlayer():GetActiveWeapon()
		
 		if wep && wep:IsValid() && wep.HUDShouldDraw != nil then
			return wep.HUDShouldDraw(wep, name)
		end
 	end
	
 	return true
end


// Called immediately after starting the gamemode 
function GM:Initialize()
	self.ShowScoreboard = false 
	
	help_text = [[As a prop you need to replicate existing props on the map && then find a good hiding spot.
	Your health is scaled based on the size of the prop you replicate.
	
	As a hunter you need to find props controlled by players && kill them.
	Shooting props that aren't controlled by players does damage to you.
	
	-= KEYBOARD SHORTCUTS =-
	[E] (Use) - Turns you into the prop you are looking at (props only).
	[F1] (Show Help) - Displays this help menu.
	[F2] (Show Team) - Shows the team selection dialog box.
	[F3] (Spare 1) - Plays a taunt sound.]]
	
	round_start_time = 0
	scoreboard = nil
	
	hunter_wins = 0
	prop_wins = 0
	
	surface.CreateFont("Arial", 16, 400, true, false, "ph_arial")
	surface.CreateFont("coolvetica", 72, 500, true, false, "ph_scoreboard_header")
	surface.CreateFont("Arial", 16, 400, true, false, "ph_scoreboard_subtitle")
	surface.CreateFont("Arial", 16, 700, true, false, "ph_scoreboard_row")
	
	if !file.Exists("prop_hunt/shown_help_menu.txt") then
		show_help_menu = 1
		file.Write("prop_hunt/shown_help_menu.txt", "You have been shown the prop hunt help menu.")
	else
		show_help_menu = 0
	end
end


// Opens the help menu
function OpenHelpMenu()
	local help_menu = vgui.Create("DFrame")
	local help_panel = vgui.Create("DPanel", help_menu)
	local help_label = vgui.Create("DLabel", help_panel)
	
	help_label:SetText(help_text)
	help_label:SetTextColor(color_black)
	help_label:SizeToContents()
	help_label:SetPos(5, 5)
	
	local w, h = help_label:GetSize()
	help_menu:SetSize(w + 20, h + 43)
	
	help_panel:StretchToParent(5, 28, 5, 5)
	
	help_menu:SetTitle("Prop Hunt Help")
	help_menu:Center()
	help_menu:MakePopup()
end
usermessage.Hook("OpenHelpMenu", OpenHelpMenu)


// Resets the player hull
function ResetHull(um)
	if LocalPlayer() && LocalPlayer():IsValid() then
		LocalPlayer():ResetHull()
	end
end
usermessage.Hook("ResetHull", ResetHull)


// Hides the scoreboard
function GM:ScoreboardHide()
	self.ShowScoreboard = false
	
	if scoreboard then
		scoreboard:SetVisible(false)
	end
end


// Shows the scoreboard
function GM:ScoreboardShow()
	self.ShowScoreboard = true
	
	if !scoreboard then
		self:CreateScoreboard()
	end
	
	scoreboard:SetVisible(true)
	scoreboard:UpdateScoreboard(true)
end


// Shows the team selection box to the player
function GM:ShowTeam()

	if ( IsValid(self.TeamSelectFrame) ) then return end
	
	// Simple team selection box
	self.TeamSelectFrame = vgui.Create( "DFrame" )
	self.TeamSelectFrame:SetTitle( "Pick Team" )
	
	local AllTeams = team.GetAllTeams()
	local y = 30
	for ID, TeamInfo in pairs ( AllTeams ) do
	
		if ( ID != TEAM_CONNECTING && ID != TEAM_UNASSIGNED ) then
	
			local Team = vgui.Create( "DButton", self.TeamSelectFrame )
				function Team.DoClick() RunConsoleCommand( "changeteam", ID ) end
				Team:SetPos( 10, y )
				Team:SetSize( 130, 20 )
				Team:SetText( TeamInfo.Name )
				
			if (  IsValid( LocalPlayer() ) && LocalPlayer():Team() == ID ) then
				Team:SetDisabled( true )
			end
				
				y = y + 30
		
		end
		
	end

	
	self.TeamSelectFrame:SetSize( 150, y )
	self.TeamSelectFrame:Center()
	self.TeamSelectFrame:MakePopup()
	self.TeamSelectFrame:SetKeyboardInputEnabled( false )
end


// Sets the local blind variable to be used in CalcView
function SetBlind(um)
	blind = um:ReadBool()
end
usermessage.Hook("SetBlind", SetBlind)


// Sets the player hull
function SetHull(um)
	hullxy = um:ReadLong()
	hullz = um:ReadLong()
	
	LocalPlayer():SetHull(Vector(hullxy * -1, hullxy * -1, 0), Vector(hullxy, hullxy, hullz))
	LocalPlayer():SetHullDuck(Vector(hullxy * -1, hullxy * -1, 0), Vector(hullxy, hullxy, hullz))
end
usermessage.Hook("SetHull", SetHull)


// Sets the round start time
function SetRoundStartTime(um)
	round_start_time = um:ReadLong()
end
usermessage.Hook("SetRoundStartTime", SetRoundStartTime)


// Displays winning time and plays victory/defeat sound
function ShowWinningTeam(um)
	local winning_team = um:ReadShort()
	
	if IsValid(LocalPlayer()) && LocalPlayer():Team() == TEAM_SPECTATOR || winning_team == LocalPlayer():Team() then
		if #VICTORY_SOUNDS > 1 then
			surface.PlaySound(VICTORY_SOUNDS[math.random(1, #VICTORY_SOUNDS)])
		elseif #VICTORY_SOUNDS > 0 then
			surface.PlaySound(VICTORY_SOUNDS[1])
		end
	else
		if #LOSS_SOUNDS > 1 then
			surface.PlaySound(LOSS_SOUNDS[math.random(1, #LOSS_SOUNDS)])
		elseif #LOSS_SOUNDS > 0 then
			surface.PlaySound(LOSS_SOUNDS[1])
		end
	end
end
usermessage.Hook("ShowWinningTeam", ShowWinningTeam)


// Updates hunter/prop wins
function UpdateWinCount(um)
	hunter_wins = um:ReadLong()
	prop_wins = um:ReadLong()
end
usermessage.Hook("UpdateWinCount", UpdateWinCount)