// Include the other needed vgui elements
include("cl_scoreboard_playerlist.lua")


// Start our new vgui element
local PANEL = {}


// Apply the scheme of things
function PANEL:ApplySchemeSettings()
	self.hunter_lbl:SetFont("ph_scoreboard_header")
	
	self.hunter_count_lbl:SetFont("ph_scoreboard_row")
	
	self.hunter_wins_lbl:SetFont("ph_scoreboard_header")
	
	self.prop_wins_lbl:SetFont("ph_scoreboard_header")
	
	self.prop_count_lbl:SetFont("ph_scoreboard_row")
	
	self.prop_lbl:SetFont("ph_scoreboard_header")

	self.hostname_lbl:SetFont("ph_scoreboard_subtitle")
	
	self.spectator_lbl:SetFont("DefaultSmall")
end


// Called when our vgui element is created
function PANEL:Init()
	self.hunter_lbl = vgui.Create("Label", self)
	self.hunter_lbl:SetText("Hunters")
	
	self.hunter_count_lbl = vgui.Create("Label", self)
	
	self.hunter_wins_lbl = vgui.Create("Label", self)
	
	self.prop_wins_lbl = vgui.Create("Label", self)
	
	self.prop_count_lbl = vgui.Create("Label", self)
	
	self.prop_lbl = vgui.Create("Label", self)
	self.prop_lbl:SetText("Props")
	
	self.hostname_lbl = vgui.Create("Label", self)
	
	self.hunter_playerlist = vgui.Create("scoreboard_playerlist", self)
	self.hunter_playerlist:SetTeam(TEAM_HUNTERS)
	
	self.prop_playerlist = vgui.Create("scoreboard_playerlist", self)
	self.prop_playerlist:SetTeam(TEAM_PROPS)
	
	self.spectator_lbl = vgui.Create("Label", self)
	
	self:UpdateScoreboard()
	timer.Create("ph_scoreboard_updater", 0.5, 0, self.UpdateScoreboard, self)
end


// Called every frame
function PANEL:Paint()
	draw.RoundedBox(10, 0, 0, self:GetWide() / 2 - 5, 60, Color(255, 220, 0, 255))
	draw.RoundedBox(10, 1, 1, self:GetWide() / 2 - 7, 58, Color(70, 100, 120, 255))
	
	draw.RoundedBox(10, self:GetWide() / 2 + 5, 0, self:GetWide() / 2 - 5, 60, Color(255, 220, 0, 255))
	draw.RoundedBox(10, self:GetWide() / 2 + 6, 1, self:GetWide() / 2 - 7, 58, Color(160, 60, 55, 255))
	
	draw.RoundedBox(10, 0, 70, self:GetWide(), self:GetTall() - 70, Color(255, 220, 0, 255))
	draw.RoundedBox(10, 1, 71, self:GetWide() - 2, self:GetTall() - 72, Color(0, 0, 0, 255))
end


// Does the actual layout
function PANEL:PerformLayout()
	self:SetSize(ScrW() * 0.85, ScrH() * 0.85)
	self:SetPos((ScrW() - self:GetWide()) / 2, (ScrH() - self:GetTall()) / 2)
	
	self.hunter_lbl:SizeToContents()
	self.hunter_lbl:SetPos(8, -1)
	
	self.hunter_count_lbl:SizeToContents()
	self.hunter_count_lbl:SetPos(self:GetWide() / 2 - self.hunter_count_lbl:GetWide() - 60, 55 - self.hunter_count_lbl:GetTall())
	
	self.hunter_wins_lbl:SizeToContents()
	self.hunter_wins_lbl:SetPos(self:GetWide() / 2 - self.hunter_wins_lbl:GetWide() - 10, -1)
	
	self.prop_wins_lbl:SizeToContents()
	self.prop_wins_lbl:SetPos(self:GetWide() / 2 + 10, -1)
	
	self.prop_count_lbl:SizeToContents()
	self.prop_count_lbl:SetPos(self:GetWide() / 2 + 60, 55 - self.hunter_count_lbl:GetTall())
	
	self.prop_lbl:SizeToContents()
	self.prop_lbl:SetPos(self:GetWide() - self.prop_lbl:GetWide() - 7, -1)
	
	self.hostname_lbl:SizeToContents()
	self.hostname_lbl:SetPos(10, 75)
	
	self.hunter_playerlist:SetPos(5, 100)
	self.hunter_playerlist:SetSize(self:GetWide() / 2 - 10, self:GetTall() - 20)
	
	self.prop_playerlist:SetPos(self:GetWide() / 2 + 5, 100)
	self.prop_playerlist:SetSize(self:GetWide() / 2 - 10, self:GetTall() - 20)
	
	self.spectator_lbl:SizeToContents()
	self.spectator_lbl:SetPos(10, self:GetTall() - 15)
end


// Updates the scoreboard
function PANEL:UpdateScoreboard(force)
	if !force && !self:IsVisible() then return end
	
	local num_hunters = #team.GetPlayers(TEAM_HUNTERS)
	if num_hunters == 1 then
		self.hunter_count_lbl:SetText("1 player")
	else
		self.hunter_count_lbl:SetText(num_hunters.." players")
	end
	
	self.hunter_wins_lbl:SetText(hunter_wins)
	
	self.prop_wins_lbl:SetText(prop_wins)
	
	local num_props = #team.GetPlayers(TEAM_PROPS)
	if num_props == 1 then
		self.prop_count_lbl:SetText("1 player")
	else
		self.prop_count_lbl:SetText(num_props.." players")
	end

	self.hostname_lbl:SetText(GetGlobalString("ServerName"))
	
	local spectator_list = ""
	for a, pl in pairs(team.GetPlayers(TEAM_SPECTATOR)) do
		if a == #team.GetPlayers(TEAM_SPECTATOR) then
			spectator_list = spectator_list..pl:Name()
		else
			spectator_list = spectator_list..pl:Name()..", "
		end
	end
	
	local num_spectators = #team.GetPlayers(TEAM_SPECTATOR)
	if num_spectators == 1 then
		self.spectator_lbl:SetText("1 spectator: "..spectator_list)
	elseif spectator_list != "" then
		self.spectator_lbl:SetText(num_spectators.." spectators: "..spectator_list)
	else
		self.spectator_lbl:SetText("")
	end
	
	self:InvalidateLayout()
	
	self.hunter_playerlist:UpdatePlayerList()
	self.prop_playerlist:UpdatePlayerList()
end


// Register our scoreboard element
vgui.Register("scoreboard", PANEL, "Panel")