// Include the other needed vgui elements
include("cl_scoreboard_playerrow.lua")


// Start our new vgui element
local PANEL = {}


// Apply the scheme of things
function PANEL:ApplySchemeSettings()
	self.name_lbl:SetFont("DefaultSmall")
	
	self.score_lbl:SetFont("DefaultSmall")
	
	self.deaths_lbl:SetFont("DefaultSmall")
	
	self.ping_lbl:SetFont("DefaultSmall")
end


// Called when our vgui element is created
function PANEL:Init()
	self.player_rows = {}
	self.team_to_list = 0
	
	self.name_lbl = vgui.Create("Label", self)
	self.name_lbl:SetText("Name")
	
	self.score_lbl = vgui.Create("Label", self)
	self.score_lbl:SetText("Score")
	
	self.deaths_lbl = vgui.Create("Label", self)
	self.deaths_lbl:SetText("Deaths")
	
	self.ping_lbl = vgui.Create("Label", self)
	self.ping_lbl:SetText("Ping")
end


// Called every frame
function PANEL:Paint()
	surface.SetDrawColor(Color(255, 255, 255, 255))
	surface.DrawLine(0, 13, self:GetWide(), 13)
end


// Does the actual layout
function PANEL:PerformLayout()
	self.name_lbl:SizeToContents()
	self.name_lbl:SetPos(58, 0)
	
	self.score_lbl:SizeToContents()
	self.score_lbl:SetPos(self:GetWide() - self.score_lbl:GetWide() - 100, 0)
	
	self.deaths_lbl:SizeToContents()
	self.deaths_lbl:SetPos(self:GetWide() - self.deaths_lbl:GetWide() - 50, 0)
	
	self.ping_lbl:SizeToContents()
	self.ping_lbl:SetPos(self:GetWide() - self.ping_lbl:GetWide() - 5, 0)
	
	local player_rows_sorted = {}
	for _, row in pairs(self.player_rows) do
		table.insert(player_rows_sorted, row)
	end
	table.sort(player_rows_sorted, function (a, b) return a:HigherOrLower(b) end)
	
	local y = 15
	for _, row in ipairs(player_rows_sorted) do
		row:SetPos(0, y)	
		row:SetSize(self:GetWide(), 35)
		row:UpdatePlayerRow()
		y = y + 35
	end
end


// Sets the team this element will list
function PANEL:SetTeam(team_id)
	self.team_to_list = team_id
end


// Updates the scoreboard
function PANEL:UpdatePlayerList()
	for pl, row in pairs(self.player_rows) do
		if !pl:IsValid() || pl:Team() != self.team_to_list then
			row:Remove()
			self.player_rows[pl] = nil
		end
	end
	
	for _, pl in pairs(team.GetPlayers(self.team_to_list)) do
		if !self.player_rows[pl] then
			local player_row = vgui.Create("scoreboard_playerrow", self)
			player_row:SetPlayer(pl)
			self.player_rows[pl] = player_row
		end
	end
	
	self:InvalidateLayout()
end


// Register our scoreboard element
vgui.Register("scoreboard_playerlist", PANEL, "Panel")