// Start our new vgui element
local PANEL = {}
local FRIEND_INDICATOR = surface.GetTextureID("VGUI/ico_friend_indicator_scoreboard")


// Apply the scheme of things
function PANEL:ApplySchemeSettings()
	local team_color = team.GetColor(self.pl:Team())
	
	self.name_lbl:SetFont("ph_scoreboard_row")
	self.name_lbl:SetTextColor(team_color)
	
	self.dead_lbl:SetFont("ph_scoreboard_row")
	self.dead_lbl:SetTextColor(team_color)
	
	self.score_lbl:SetFont("ph_scoreboard_row")
	self.score_lbl:SetTextColor(team_color)
	
	self.deaths_lbl:SetFont("ph_scoreboard_row")
	self.deaths_lbl:SetTextColor(team_color)
	
	self.ping_lbl:SetFont("ph_scoreboard_row")
	self.ping_lbl:SetTextColor(team_color)
end


// Figures out where to place itself
function PANEL:HigherOrLower(row)
	if !self.pl:IsValid() || self.pl:Team() == TEAM_CONNECTING then return false end
	if !row.pl:IsValid() || row.pl:Team() == TEAM_CONNECTING then return true end
	
	if self.pl:Frags() == row.pl:Frags() then
		return self.pl:Deaths() < row.pl:Deaths()
	end

	return self.pl:Frags() > row.pl:Frags()
end


// Called when our vgui element is created
function PANEL:Init()
	self.pl = 0
	
	self.avatar_img = vgui.Create("AvatarImage", self)
	
	self.name_lbl = vgui.Create("DLabel", self)
	
	self.dead_lbl = vgui.Create("DLabel", self)
	
	self.score_lbl = vgui.Create("DLabel", self)
	
	self.deaths_lbl = vgui.Create("DLabel", self)
	
	self.ping_lbl = vgui.Create("DLabel", self)
end


// Called every frame
function PANEL:Paint()
	if LocalPlayer() == self.pl then
		surface.SetDrawColor(Color(125, 125, 125, 75))
		surface.DrawRect(0, 0, self:GetWide(), self:GetTall())
	end
	
	if self.pl:GetFriendStatus() == "friend" then
		surface.SetTexture(FRIEND_INDICATOR)
		surface.DrawTexturedRect(0, 0, 64, 64) 
	end
end


// Does the actual layout
function PANEL:PerformLayout()
	self.avatar_img:SetPos(23, 1)
	self.avatar_img:SetSize(32, 32)
	
	self.name_lbl:SizeToContents()
	self.name_lbl:SetPos(58, 9)
	
	self.dead_lbl:SizeToContents()
	self.dead_lbl:SetPos(self:GetWide() - self.dead_lbl:GetWide() - 150, 9)
	
	self.score_lbl:SizeToContents()
	self.score_lbl:SetPos(self:GetWide() - self.score_lbl:GetWide() - 100, 9)
	
	
	self.deaths_lbl:SizeToContents()
	self.deaths_lbl:SetPos(self:GetWide() - self.deaths_lbl:GetWide() - 50, 9)
	
	self.ping_lbl:SizeToContents()
	self.ping_lbl:SetPos(self:GetWide() - self.ping_lbl:GetWide() - 5, 9)
end


// Sets the player in question
function PANEL:SetPlayer(pl)
	self.pl = pl
	self.avatar_img:SetPlayer(pl)
end


// Updates the scoreboard
function PANEL:UpdatePlayerRow()
	self.name_lbl:SetText(self.pl:Name())
	
	if self.pl:GetNWInt("dead") == 1 then
		self.dead_lbl:SetText("Dead")
	else
		self.dead_lbl:SetText("")
	end
	
	self.score_lbl:SetText(self.pl:Frags())
	
	self.deaths_lbl:SetText(self.pl:Deaths())
	
	self.ping_lbl:SetText(self.pl:Ping())
	
	self:InvalidateLayout()
end


// Register our scoreboard element
vgui.Register("scoreboard_playerrow", PANEL, "Panel")